@@ -18,9 +18,9 @@ class BaseTagField(with_metaclass(models.SubfieldBase, models.CharField)):
     def get_prep_value(self, value):
         prep_value = self.to_python(value)
         if prep_value.self_closed:
-            return self.to_python(value).meta_content
+            return prep_value.meta_content
         else:
-            return self.to_python(value).tag_value
+            return prep_value.tag_value
 
     def db_type(self, connection):
         return 'VARCHAR(%s)' % self.max_length
@@ -35,9 +35,9 @@ class BaseURLTagField(with_metaclass(models.SubfieldBase, models.URLField)):
     def get_prep_value(self, value):
         prep_value = self.to_python(value)
         if prep_value.self_closed:
-            return self.to_python(value).meta_content
+            return prep_value.meta_content
         else:
-            return self.to_python(value).tag_value
+            return prep_value.tag_value
 
 
 class BaseImageTagField(with_metaclass(models.SubfieldBase, models.ImageField)):
@@ -49,9 +49,9 @@ class BaseImageTagField(with_metaclass(models.SubfieldBase, models.ImageField)):
     def get_prep_value(self, value):
         prep_value = self.to_python(value)
         if prep_value.self_closed:
-            return self.to_python(value).meta_content
+            return prep_value.meta_content
         else:
-            return self.to_python(value).tag_value
+            return prep_value.tag_value
 
     def pre_save(self, model_instance, add):
         "Returns field's value just before saving."
@@ -104,7 +104,7 @@ class MetaTagField(with_metaclass(models.SubfieldBase, BaseTagField)):
         if isinstance(value, MetaTag):
             return value
         content = super(MetaTagField, self).to_python(value)
-        meta_tag = MetaTag(**{'name': self.name, 'value': content})
+        meta_tag = MetaTag(meta_name=self.name, **{'name': self.name, 'value': content})
         return meta_tag
 
 
@@ -124,7 +124,7 @@ class URLMetaTagField(with_metaclass(models.SubfieldBase, BaseURLTagField)):
         if isinstance(value, MetaTag):
             return value
         content = super(URLMetaTagField, self).to_python(value)
-        meta_tag = MetaTag(**{'name': self.name, 'value': content})
+        meta_tag = MetaTag(meta_name=self.name, **{'name': self.name, 'value': content})
         return meta_tag
 
 
@@ -144,7 +144,7 @@ class ImageMetaTagField(with_metaclass(models.SubfieldBase, BaseImageTagField)):
         if isinstance(value, ImageMetaTag):
             return value
         content = super(ImageMetaTagField, self).to_python(value)
-        image_meta_tag = ImageMetaTag(**{'name': self.name, 'value': content, 'path': self.upload_to})
+        image_meta_tag = ImageMetaTag(meta_name=self.name, **{'name': self.name, 'value': content, 'path': self.upload_to})
         return image_meta_tag
 
 
@@ -167,5 +167,5 @@ class KeywordsTagField(with_metaclass(models.SubfieldBase, BaseTagField)):
         if isinstance(value, KeywordsTag):
             return value
         keywords = super(KeywordsTagField, self).to_python(value)
-        keyword_tag = KeywordsTag(**{'name': self.name, 'value': keywords})
+        keyword_tag = KeywordsTag(meta_name=self.name, **{'name': self.name, 'value': keywords})
         return keyword_tag
\ No newline at end of file
